require("./check-versions")();

let config = require("../../config");
if (!process.env.NODE_ENV) {
  process.env.NODE_ENV = JSON.parse(config.dev.env.NODE_ENV);
}

let opn = require("opn");
let path = require("path");
let express = require("express");
let webpack = require("webpack");
let proxyMiddleware = require("http-proxy-middleware");
let webpackConfig = require("./webpack.dev.conf");

// 启动mock数据
let mock = require("./mock");
let apiRoutes = express.Router();

// default port where dev server listens for incoming traffic
let port = process.env.PORT || config.dev.port;
// automatically open browser, if not set will be false
let autoOpenBrowser = !!config.dev.autoOpenBrowser;
// Define HTTP proxies to your custom API backend
// https://github.com/chimurai/http-proxy-middleware
let proxyTable = config.dev.proxyTable;

let app = express();
let compiler = webpack(webpackConfig);

let devMiddleware = require("webpack-dev-middleware")(compiler, {
  publicPath: webpackConfig.output.publicPath,
  quiet: true
});

let hotMiddleware = require("webpack-hot-middleware")(compiler, {
  log: false,
  heartbeat: 2000
});
// force page reload when html-webpack-plugin template changes
// compiler.plugin('compilation', function (compilation) {
//   compilation.plugin('html-webpack-plugin-after-emit', function (data, cb) {
//     hotMiddleware.publish({ action: 'reload' })
//     cb()
//   })
// })

// proxy api requests
Object.keys(proxyTable).forEach(function(context) {
  let options = proxyTable[context];
  if (typeof options === "string") {
    options = { target: options };
  }
  app.use(proxyMiddleware(options.filter || context, options));
});

// 启动mock
mock(apiRoutes);
app.use(apiRoutes);
// app.use('/api', apiRoutes)

// handle fallback for HTML5 history API
app.use(require("connect-history-api-fallback")());

// serve webpack bundle output
app.use(devMiddleware);

// enable hot-reload and state-preserving
// compilation error display
app.use(hotMiddleware);

// serve pure static assets
let staticPath = path.posix.join(
  config.dev.assetsPublicPath,
  config.dev.assetsSubDirectory
);
app.use(staticPath, express.static("./static"));

const uri = "http://localhost:" + port;

var _resolve;
var _reject;
var readyPromise = new Promise((resolve, reject) => {
  _resolve = resolve;
  _reject = reject;
});

var server;
var portfinder = require("portfinder");
portfinder.basePort = port;

console.log("> Starting dev server...");
devMiddleware.waitUntilValid(() => {
  portfinder.getPort((err, port) => {
    if (err) {
      _reject(err);
    }
    process.env.PORT = port;
    var uri = "http://localhost:" + port;
    console.log("> Listening at " + uri + "\n");
    // when env is testing, don't need open it
    if (autoOpenBrowser && process.env.NODE_ENV !== "testing") {
      opn(uri, { app: ["google chrome", "--incognito"] });
    }
    server = app.listen(port);
    _resolve();
  });
});

module.exports = {
  ready: readyPromise,
  close: () => {
    server.close();
  }
};
